
---

## วิธีใช้

```py
import other_python as otpy
print(otpy.change(1,9))# possible output -8,-7,-6,-5,-4,-3,-2,-1,0,1,2,3,4,5,6,7,8
print(otpy.find_path())# possible output C:\Users\User\Desktop\python\...

```
